@@ -1,26 +1,34 @@
-/* The GIMP -- an image manipulation program
- * Copyright (C) 1995-1997 Spencer Kimball and Peter Mattis
+/* GIMP Plug-in Template
+ * Copyright (C) 2000  Michael Natterer <mitch@gimp.org> (the "Author").
+ * All Rights Reserved.
  *
- * GIMP Plug-In Template
- * Copyright (C) 2000  Michael Natterer <mitch@gimp.org>
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
+ * 
+ * The above copyright notice and this permission notice shall be included
+ * in all copies or substantial portions of the Software.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+ * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
+ * THE AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
+ * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+ * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ * 
+ * Except as contained in this notice, the name of the Author of the
+ * Software shall not be used in advertising or otherwise to promote the
+ * sale, use or other dealings in this Software without prior written
+ * authorization from the Author.
  */
 
 #include "config.h"
 
+#include <string.h>
+
 #include <libgimp/gimp.h>
 #include <libgimp/gimpui.h>
 
@@ -44,11 +52,11 @@
 /*  Local function prototypes  */
 
 static void   query (void);
-static void   run   (gchar      *name,
-		     gint        nparams,
-		     GimpParam  *param,
-		     gint       *nreturn_vals,
-		     GimpParam **return_vals);
+static void   run   (const gchar      *name,
+		     gint              nparams,
+		     const GimpParam  *param,
+		     gint             *nreturn_vals,
+		     GimpParam       **return_vals);
 
 
 /*  Local variables  */
@@ -124,11 +132,11 @@ query (void)
 }
 
 static void
-run (gchar      *name, 
-     gint        n_params, 
-     GimpParam  *param, 
-     gint       *nreturn_vals,
-     GimpParam **return_vals)
+run (const gchar      *name, 
+     gint              n_params, 
+     const GimpParam  *param, 
+     gint             *nreturn_vals,
+     GimpParam       **return_vals)
 {
   static GimpParam   values[1];
   GimpDrawable      *drawable;
@@ -139,6 +147,13 @@ run (gchar      *name,
   *nreturn_vals = 1;
   *return_vals  = values;
 
+  /*  Initialize i18n support  */
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
+  textdomain (GETTEXT_PACKAGE);
+
   run_mode = param[0].data.d_int32;
   image_ID = param[1].data.d_int32;
   drawable = gimp_drawable_get (param[2].data.d_drawable);
@@ -172,7 +187,6 @@ run (gchar      *name,
 	  gimp_get_data (DATA_KEY_VALS,    &vals);
 	  gimp_get_data (DATA_KEY_UI_VALS, &ui_vals);
 
-	  INIT_I18N ();
 	  if (! dialog (image_ID, drawable,
 			&vals, &image_vals, &drawable_vals, &ui_vals))
 	    {
